# Bandsaw

Bandsaw is a library for defining and structuring Python workflows, that can span
across multiple python interpreters and machines. It is currently under development
by [Kantai GmbH](https://kant.ai) and licensed under
[MIT License](https://gitlab.com/kantai/bandsaw/-/blob/mainline/LICENSE).

### Interested in first steps using bandsaw?
Take a look at our [Getting started documentation](./getting_started/).

### Want to learn more about the details?
Read through our [User guide](./user_guide/) to understand how it works.

### You have questions?
Maybe we already have the [answers](./faq/). If you can't find the answers
there, reach out to us. Our support channels can be found on our [documentation home](https://docs.kant.ai)
on [https://docs.kant.ai](https://docs.kant.ai).

